# Modeling and Reports
One of the main reasons for any modeling activity is that you are trying to get specific insights with reports. This is why thinking backward makes sense – a rule we always recommend applying when using SAP LeanIX. First, get an understanding of what are the reports and views you want to create (keeping in mind the audience of that as well), then explore which options you have in SAP LeanIX, and identify the most intelligent way of doing it: Use default settings and fields first, add tags only if you need them, etc. This will avoid getting lost in the variety of options SAP LeanIX offers – to stay lean with your enterprise architecture work.
Not all default fields on fact sheets are automatically listed in filters and the drop-down selection of views on reports. To make them visible, enable the Include in views and Show in filters options per field in the meta model configuration. To learn more about these options, see [Showing Fields in Views](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759fb817a44101492ded5b080b9f10c__showing_fields_in_views) and [Showing Fields in Filters](https://help.sap.com/docs/leanix/ea/fact-sheet-fields?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759fb817a44101492ded5b080b9f10c__showing_fields_in_filters).
The below example shows what thinking backward means and how you can apply it in SAP LeanIX.
